@@ -99,7 +99,7 @@ function gPanelContainer()
 }
 
 function izOnMouseOut(e) {
-		if ((e.originalTarget.tagName.toUpperCase() == "HTML") || (e.originalTarget.tagName == "xul:browser")){
+		if ((e.originalTarget.tagName.toLowerCase() == "html") || (e.originalTarget.tagName.toLowerCase() == "xul:browser")){
 			cancelScrollZoom();
 		}
 }
@@ -128,6 +128,7 @@ function reportStatus(oizImage){
 	{
 		statusTextFld = document.getElementById("statusbar-display");
 	}
+	
     	statusTextFld.label = "Image Zoom: " + oizImage.zoomFactor() + "% | " + imagezoomBundle.getString("widthLabel") + ": " + oizImage.getWidth() + "px | " + imagezoomBundle.getString("heightLabel") + ": " + oizImage.getHeight() + "px";
 }
 
@@ -186,7 +187,7 @@ function izSetZoom(zFactor)
 }
 
 function disableContextMenu(e) {
-	if (document.popupNode.tagName == "IMG") {
+	if (document.popupNode.tagName.toLowerCase() == "img") {
 		linuxImage = document.popupNode;
 		izContext = e.originalTarget;
 		e.preventDefault();
@@ -197,8 +198,10 @@ function disableContextMenu(e) {
 
 function izOnMouseDown(e){
 
+	var targetName  = e.originalTarget.tagName.toLowerCase();
+	
 	if (
-	     (e.originalTarget.tagName == "IMG") &&
+	     (targetName == "img") &&
 	     (mousedown) &&
 	     (
 	       (e.which == nsIPrefBranchObj.getIntPref("imageresetbutton")) || 
@@ -212,10 +215,13 @@ function izOnMouseDown(e){
 	}
 	
 	// prepare for the mouse functions on a right click when user option is true
-	if ((e.which == nsIPrefBranchObj.getIntPref("triggerbutton")) && (nsIPrefBranchObj.getBoolPref("usescroll")))
+	if ((e.which == nsIPrefBranchObj.getIntPref("triggerbutton")) && 
+	    (nsIPrefBranchObj.getBoolPref("usescroll")) &&
+	    // Prevent zooming from being initiated when an embedded object is clicked apon
+	    !(targetName == "embed" || targetName == "object"))
 	{
 				
-		if ((e.originalTarget.tagName == "IMG") || (nsIPrefBranchObj.getIntPref("scrollZoomMode") != 2))
+		if ((targetName == "img") || (nsIPrefBranchObj.getIntPref("scrollZoomMode") != 2))
 		{
 			if (nsIPrefBranchObj.getIntPref("scrollZoomMode") == 2) 
 			{
@@ -248,6 +254,9 @@ function izOnMouseUp(e){
 }
 
 function izOnMouseClick(e){
+
+	var targetName  = e.originalTarget.tagName.toLowerCase();
+	
 	if (e.which == nsIPrefBranchObj.getIntPref("triggerbutton")){
 		if (haveZoomed){
 			e.preventDefault();
@@ -265,7 +274,7 @@ function izOnMouseClick(e){
 
 	if (mousedown){
 		// Invoke varios mouse function when mouse is over an image only
-		if (e.originalTarget.tagName == "IMG") {
+		if (targetName == "img") {
 			switch(e.which){
 			// Middle mouse button pressed while right button down, reset image
 			case nsIPrefBranchObj.getIntPref("imageresetbutton"):
@@ -300,11 +309,11 @@ function ScrollImage(e){
 		
 		// Mixed Mode (default)
 		case 0:
-			if ((e.target.tagName == "IMG") || (linuxImage != null) || (currentImage != null))
+			if ((e.target.tagName.toLowerCase() == "img") || (linuxImage != null) || (currentImage != null))
 			{
 				if (linuxImage != null) {
 					currentImage = linuxImage;
-				} else if (e.target.tagName == "IMG") {
+				} else if (e.target.tagName.toLowerCase() == "img") {
 					currentImage = e.target;
 				}
 			} 
@@ -317,11 +326,11 @@ function ScrollImage(e){
 		
 		// Only Scroll when mouse over image mode
 		case 1:
-			if ((e.target.tagName == "IMG") || (linuxImage != null))
+			if ((e.target.tagName.toLowerCase() == "img") || (linuxImage != null))
 			{
 				if (linuxImage != null) {
 					imageToScroll = linuxImage;
-				} else if (e.target.tagName == "IMG") {
+				} else if (e.target.tagName.toLowerCase() == "img") {
 					imageToScroll = e.target;
 				}				
 			}
@@ -354,13 +363,26 @@ function ScrollImage(e){
 			haveZoomed = true;
 			var oizImage = new izImage(imageToScroll);
 
-			if (((e.detail < 0) && !nsIPrefBranchObj.getBoolPref("reversescrollzoom")) ||
-				((e.detail > 0) && nsIPrefBranchObj.getBoolPref("reversescrollzoom")))
-				var zoomFactor = 1/(1+(nsIPrefBranchObj.getIntPref("scrollvalue")/100));
-			else
-				var zoomFactor = 1+(nsIPrefBranchObj.getIntPref("scrollvalue")/100);
+			if (nsIPrefBranchObj.getIntPref("scrollmode") == 0) 
+			{
+				if (((e.detail < 0) && !nsIPrefBranchObj.getBoolPref("reversescrollzoom")) ||
+					((e.detail > 0) && nsIPrefBranchObj.getBoolPref("reversescrollzoom")))
+					var zoomFactor = 1/(1+(nsIPrefBranchObj.getIntPref("scrollvalue")/100));
+				else
+					var zoomFactor = 1+(nsIPrefBranchObj.getIntPref("scrollvalue")/100);
 
-			oizImage.zoom(zoomFactor);
+				oizImage.zoom(zoomFactor);
+			}
+			else
+			{
+				if (((e.detail < 0) && !nsIPrefBranchObj.getBoolPref("reversescrollzoom")) ||
+					((e.detail > 0) && nsIPrefBranchObj.getBoolPref("reversescrollzoom")))
+					var zoomFactor = oizImage.zoomFactor() - nsIPrefBranchObj.getIntPref("scrollvalue");
+				else
+					var zoomFactor = oizImage.zoomFactor() + nsIPrefBranchObj.getIntPref("scrollvalue");
+
+				oizImage.setZoom(zoomFactor);
+			}
 			reportStatus(oizImage);
 		}		
 	} else {
