@@ -19,9 +19,10 @@ pref("imagezoom.smZoomPcts", true);
 pref("imagezoom.zoomvalue", 200);
 pref("imagezoom.version", "0.0.0");
 pref("imagezoom.reversescrollzoom", false);
+pref("imagezoom.scrollmode", 0);
 pref("imagezoom.showViewMenu", true);
 pref("imagezoom.defaultGlobalZoom", "100");
 pref("imagezoom.scrollZoomMode", 0);
 pref("imagezoom.autofitlargeimage", false);
-pref("imagezoom.showAutoFitInMenu", false);
-pref("extensions.{1A2D0EC4-75F5-4c91-89C4-3656F6E44B68}.description", "chrome://imagezoom/locale/imageZoom.properties");
\ No newline at end of file
+pref("imagezoom.showAutoFitInMenu", true);
+pref("extensions.{1A2D0EC4-75F5-4c91-89C4-3656F6E44B68}.description", "chrome://imagezoom/locale/imageZoom.properties");
